@@ -93,6 +93,38 @@ class Firebot:
         message = "Successfully sent chat message as bot"
         self.sendit(data, message)
 
+    def whisper_chatbot(self, username, chatmessage):
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:chat",
+                        "chatter": "Bot",
+                        "whisper": username,
+                        "message": chatmessage,
+                    }
+                ]
+            }
+        }
+        message = "Successfully sent whisper chat message as bot"
+        self.sendit(data, message)
+
+    def whisper_chatstreamer(self, username, chatmessage):
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:chat",
+                        "chatter": "Streamer",
+                        "whisper": username,
+                        "message": chatmessage,
+                    }
+                ]
+            }
+        }
+        message = "Successfully sent whisper chat message as streamer"
+        self.sendit(data, message)
+
     def streamer_chat(self, chatmessage):
         data = {
             "effects": {
@@ -222,12 +254,13 @@ class Firebot:
         message = "Successfully executed AWS Polly effect"
         self.sendit(data, message)
 
-    def customvariable(self, varname, vardata):
+    def customvariable(self, varname, vardata, duration=0):
         data = {
             "effects": {
                 "list": [
                     {
                         "type": "firebot:customvariable",
+                        "ttl": duration,
                         "name": varname,
                         "variableData": vardata,
                     }
@@ -587,9 +620,128 @@ class Firebot:
         rjson = r.json()
         return rjson
 
+    def get_countervalue(self, name):
+        with open(f'{self.directory}Firebot/v5/profiles/Main Profile/counters/counters.json', 'r') as f:
+            data = json.load(f)
+        counters = data.keys()
+        for counter in counters:
+            if name == data[counter]['name']:
+                value = int(data[counter]['value'])
+        f.close()
+        return value
 
-api = Firebot(f"C:/Users/baile/AppData/Roaming/",
-              "http://localhost:7472/")
+    def view_rolemembers(self, rolename, username):
+        with open(f'{self.directory}Firebot/v5/profiles/Main Profile/roles/customroles.json', 'r') as f:
+            data = json.load(f)
+        roles = data.keys()
+        for role in roles:
+            if rolename == data[role]['name']:
+                role = data[role]['viewers']
+                if username in role:
+                    in_role = True
+                else:
+                    in_role = False
+            else:
+                print(f"Did not find {rolename}. Check your spelling")
+        f.close()
+        return in_role
 
+    def get_command(self, name):
+        with open(f'{self.directory}Firebot/v5/profiles/Main Profile/chat/commands.json', 'r') as f:
+            data = json.load(f)
+            x = data['customCommands']
+        commands = data.keys()
+        for command in x:
+            print(x[command][name])
 
-api.disable_allconnections()
+    def add_currency_online(self, currency, amount):
+        """
+        Adds currency to all online viewers
+        """
+        currencyid = self.get_currencyid(currency)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:currency",
+                        "action": "Add",
+                        "currency": currencyid,
+                        "amount": amount,
+                        "target": "allOnline",
+                    }
+                ]
+            }
+        }
+        message = f"Successfully added {amount} {currency} to all online viewers"
+        self.sendit(data, message)
+
+    def remove_currency_online(self, currency, amount):
+        """
+        Removes currency from all online viewers
+        """
+        currencyid = self.get_currencyid(currency)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:currency",
+                        "action": "Remove",
+                        "currency": currencyid,
+                        "amount": amount,
+                        "target": "allOnline",
+                    }
+                ]
+            }
+        }
+        message = f"Successfully added {amount} {currency} to all online viewers"
+        self.sendit(data, message)
+
+    def add_currency_role(self, currency, amount, role):
+        """
+        Adds currency to a specific role
+        """
+        currencyid = self.get_currencyid(currency)
+        roleid = self.get_roleid(role)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:currency",
+                        "roleIds": [
+                            roleid
+                        ],
+                        "action": "Add",
+                        "currency": currencyid,
+                        "amount": amount,
+                        "target": "group",
+                    }
+                ]
+            }
+        }
+        message = f"Successfully added {amount} {currency} to all users in {role} role"
+        self.sendit(data, message)
+
+    def remove_currency_role(self, currency, amount, role):
+        """
+        Removes currency from a specific role
+        """
+        currencyid = self.get_currencyid(currency)
+        roleid = self.get_roleid(role)
+        data = {
+            "effects": {
+                "list": [
+                    {
+                        "type": "firebot:currency",
+                        "roleIds": [
+                            roleid
+                        ],
+                        "action": "Remove",
+                        "currency": currencyid,
+                        "amount": amount,
+                        "target": "group",
+                    }
+                ]
+            }
+        }
+        message = f"Successfully removed {amount} {currency} to all users in {role} role"
+        self.sendit(data, message)
